@@ -9,7 +9,8 @@ from model_utils.choices import Choices
 from rest_framework import serializers
 
 from easys_ordermanager.fields import PhoneNumberField
-from easys_ordermanager.validators import comma_separated_period_validatior, DomainNameValidator, HexColorValidator
+from easys_ordermanager.validators import comma_separated_period_validatior, HexColorValidator, \
+    DomainNameValidator
 
 PAYMENT_METHOD_TRANSFER = 1
 PAYMENT_METHOD_CHARGE = 2
